@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2006 - 2007 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2006-2007 Volker Krause <vkrause@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -24,7 +24,7 @@ using namespace MailTransport;
 TransportMgr::TransportMgr()
     : mCurrentJob(nullptr)
 {
-    QVBoxLayout *vbox = new QVBoxLayout(this);
+    auto *vbox = new QVBoxLayout(this);
     vbox->setContentsMargins(0, 0, 0, 0);
 
     vbox->addWidget(new TransportManagementWidget(this));
@@ -117,7 +117,7 @@ int main(int argc, char **argv)
     QApplication app(argc, argv);
     app.setApplicationName(QStringLiteral("transportmgr"));
 
-    TransportMgr *t = new TransportMgr();
+    auto *t = new TransportMgr();
     t->show();
     app.exec();
     delete t;
